from __future__ import absolute_import

import os

import unittest

class TestCase(unittest.TestCase):
    def tearDown(self):
        if os.path.exists('expected'):
            os.unlink('expected')
        if os.path.exists('got'):
            os.unlink('got')

    def assertTextEquals(self, got, expected, msg=None):
        if got != expected:
            file('expected', 'w').write(expected)
            file('got', 'w').write(got)
            os.system('diff -u expected got')

        self.assertEquals(got, expected, msg)

class main():
    def __init__(self, module='__main__', argv=None):
        unittest.main(module=module, argv=argv)



from package.unittest import *

import crockford

class TestFunctions(TestCase):
    def test_encode(self):
        self.assertEquals(
            crockford.b32encode('foo'),
            'CSQPY',
            'b32encode works'
        )

    def test_decode(self):
        self.assertEquals(
            crockford.b32decode('CSQPY'),
            'foo',
            'b32decode works'
        )

if __name__ == '__main__':
    main()



"""\
This module provides package management support stuff.
"""

import sys

ENONAME = """
The 'name' entry is required in your `info.yaml` file.

"""

ENOSETUP = """
For some bizarre reason, I cannot locate your Python 'setuptools' or
'distutils' packages. Paint me pathetic, but I just cannot go on at this
point.

"""

ENOINFO = """
I can't find the 'package.info' module. If you are the author of this package,
please run this command:

    make package-info

If you are simply some dude installing this Python package, please contact the
author about the missing 'package.info' module.

"""

ENOYAML = """
You need to install pyyaml to use the package-py framework as a package author.

"""

ENOLOCALINFO = """
Strange. I can't find the file called ./package/info.yaml. Did you delete it?

"""

ELOCALINFONOTSET = """
It seems like you haven't edited the ./package/info.yaml file yet. You need to
put all the pertinent information in there in order to proceed.

"""

ENOSETUPTOOLS = """
The package you are trying to install depends on an installation feature that
requires the 'setuptools' Python module, but you do not have that module
installed. You will need to install 'setuptools' before proceeding with this
install.

You can find setuptools here:

    http://pypi.python.org/pypi/setuptools/

"""

EBADINFO = """
It seems like some of your package/info.yaml settings are wrong.
Check that file and try again. Your exception msg was:

%(err)s
"""

def die(msg, err=''):
    sys.stderr.write(msg % locals())
    sys.exit(1)



"""\
Encode and decode using Douglas Crockford's base32 encoding scheme:

    http://www.crockford.com/wrmg/base32.html

The module uses the base64 module's API for base32 functions:

    base64.b32encode(s)
    base64.b32decode(s[, casefold[, map01]])

See base64 for more info.
"""

__version__ = '0.0.2'

import base64, string

__std2crock = string.maketrans(
    "ABCDEFGHIJKLMNOPQRSTUVWXYZ234567",
    "0123456789ABCDEFGHJKMNPQRSTVWXYZ"
)
__crock2std = string.maketrans(
    "0123456789ABCDEFGHJKMNPQRSTVWXYZ",
    "ABCDEFGHIJKLMNOPQRSTUVWXYZ234567"
)

def b32encode(s):
    return base64.b32encode(s).translate(__std2crock, '=')

def b32decode(b32, casefold=None, map01=None):
    # Ensure the manatory padding is correct:
    b32 += '=' * ((8 - len(b32) % 8) % 8)
    return base64.b32decode(b32.translate(__crock2std),
        casefold=casefold, map01=map01)



def get():
    info = {}
    info.update(
{ 'author': 'Ingy dot Net',
  'author_email': 'ingy@ingy.net',
  'classifiers': [ 'Development Status :: 2 - Pre-Alpha',
                   'License :: OSI Approved :: BSD License',
                   'Programming Language :: Python',
                   'Intended Audience :: Developers'],
  'description': "Encode and decode using Douglas Crockford's base32 encoding scheme:",
  'long_description': 'crockford - Encode and Decode using the Crockford Base32 scheme\n---------------------------------------------------------------\n\nInstallation\n------------\n\nUse::\n\n    > sudo pip install crockford\n\nor::\n\n    > sudo easy install crockford\n\nor::\n\n    > git clone git://github.com/ingydotnet/crockford-py.git\n    > cd crockford-py\n    > sudo make install\n\nUsage\n-----\n\n    import crockford\n\n    base32 = crockford.b32encode(string)\n    string = crockford.b32decode(base32)\n\nAuthors\n-------\n\n* Ingy dot Net <ingy@ingy.net>\n\nCopyright\n---------\n\ncrockford is Copyright (c) 2011, Ingy dot Net\n\ncrockford is licensed under the New BSD License. See the LICENSE file.\n',
  'name': 'crockford',
  'packages': ['crockford'],
  'scripts': [],
  'url': 'http://github.com/ingydotnet/crockford-py/',
  'version': '0.0.2'}
)
    return info



"""\
package - The Python package package package
"""

import os, sys, glob
from distutils.core import Command

__version__ = '0.1.1'

has_setuptools = False

from package.errors import *

try:
    from setuptools import setup as real_setup
    has_setuptools = True
except ImportError, err:
    try:
        from distutils.core import setup as real_setup
    except ImportError, err:
        die(ENOSETUP)

class setup():
    def __init__(self):
        args = self.get_args()
        self.check_args(args)
        real_setup(**args)

    def get_args(self):
        try:
            import package.info
        except ImportError, err:
            die(ENOINFO)

        args = package.info.get()
        args['cmdclass'] = {
            'test': Test,
            'devtest': DevTest,
        }
        return args

    def check_args(self, args):
        if args.get('install_requires') and 'install' in sys.argv:
            if not has_setuptools:
                die(ENOSETUPTOOLS)


class Test(Command):
    user_options = []
    test_dir = 'tests'

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        build_cmd = self.get_finalized_command('build')
        build_cmd.run()
        sys.path.insert(0, build_cmd.build_lib)
        sys.path.insert(0, self.test_dir)
        def exit(code):
            pass
        sys.exit = exit

        for test in glob.glob(self.test_dir + '/test*.py'):
            name = test[test.index('/') + 1: test.rindex('.')]
            module = __import__(name)
            module.main(module=module, argv=[''])

class DevTest(Test):
    test_dir = 'dev-tests'



"""\
This setup.py was provided by `package`, the Python package package package.

See http://pypi.python.org/pypi/package/ for more information.
"""

import sys
sys.path.insert(0, '')
import package
package.setup()



from package.unittest import *

class TestImport(TestCase):
    def test_import(self):
        import crockford

        self.assertTrue(True, 'crockford module imported cleanly')

if __name__ == '__main__':
    main()
